@@ -35,7 +35,7 @@ Chart::Clicker::Shape::Arc represents an arc.
 
  use Chart::Clicker::Shape::Arc;
 
- my $arc = Chart::Clicker::Shape::Arc({
+ my $arc = new Chart::Clicker::Shape::Arc({
     angle1 => 0,
     angle2 => 360,
     ragius => 5
